package Bundle::Locale::CLDR::Micronesianregion;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Micronesianregion

=head1 CONTENTS

Locale::CLDR::Locales::En::Latn::Fm 0.46.0

Locale::CLDR::Locales::En::Latn::Gu 0.46.0

Locale::CLDR::Locales::En::Latn::Ki 0.46.0

Locale::CLDR::Locales::En::Latn::Mh 0.46.0

Locale::CLDR::Locales::En::Latn::Mp 0.46.0

Locale::CLDR::Locales::En::Latn::Nr 0.46.0

Locale::CLDR::Locales::En::Latn::Pw 0.46.0

Locale::CLDR::Locales::En::Latn::Um 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0


=cut

1;

